@@ -23,7 +23,7 @@ def unprovide():
     exit(10)
 
 
-def tonicDNSClient(uri, method, token, data):
+def tonicDNSClient(uri, method, token, data, keyword=''):
     import sys
     import json
     if sys.version_info > (2, 6) and sys.version_info < (2, 8):
@@ -52,13 +52,52 @@ def tonicDNSClient(uri, method, token, data):
     # response body
     if method == 'GET':
         datas = json.loads(url.read().decode('utf-8'))
-        print(json.dumps(datas, sort_keys=True, indent=2))
-
+        # filtering with keyword
+        if keyword:
+            records = searchRecord(datas, keyword)
+            datas.update({"records": records})
+        formattedPrint(datas)
     else:
         data = url.read()
         print(data)
 
 
+def formattedPrint(datas):
+    import sys
+    if sys.version_info > (2, 6) and sys.version_info < (2, 8):
+        import utils2 as utils
+    elif sys.version_info > (3, 0):
+        import utils3 as utils
+
+    print("domain: %(name)s" % datas)
+    print("serial: %(notified_serial)s" % datas)
+    print("DNS   : %(type)s" % datas)
+    hr()
+    print('%-33s %-5s %-25s %-5s %-3s'
+          % ('name', 'type', 'content', 'ttl', 'prio'))
+    hr()
+    for record in datas['records']:
+        utils.print_inline("%(name)-33s" % record)
+        if record['type'] == 'SOA':
+            print("%(type)-5s" % record)
+        else:
+            utils.print_inline("%(type)-5s" % record)
+        if record['type'] == 'SOA':
+            utils.print_inline(">\t\t%(content)-25s " % record)
+        else:
+            utils.print_inline("%(content)-25s" % record)
+        if record['priority']:
+            utils.print_inline("%(ttl)5s" % record)
+            print("%(priority)2s" % record)
+        else:
+            print("%(ttl)5s " % record)
+    hr()
+
+
+def hr():
+    print('=' * 78)
+
+
 def createZoneRecords():
     # ContentType: application/json
     # x-authentication-token: token
@@ -85,11 +124,11 @@ def deleteRecords(server, token, data):
         tonicDNSClient(uri, method, token, i)
 
 
-def getZone(server, token, domain):
+def getZone(server, token, domain, keyword=''):
     # x-authentication-token: token
     method = 'GET'
     uri = 'https://' + server + '/zone/' + domain
-    tonicDNSClient(uri, method, token, data=False)
+    tonicDNSClient(uri, method, token, data=False, keyword=keyword)
 
 
 def getAllZone(server, token):
@@ -141,3 +180,16 @@ def getAllTemplates():
     # method: GET
     # uri: /template
     unprovide()
+
+
+def searchRecord(datas, keyword):
+    # search target JSON -> dictionary
+    # key target is "name" or "content"
+    # type is "type", default null
+    # either key and type, or on the other hand
+    # data is dictionaly
+    result = []
+    for record in datas['records']:
+        if record['name'].find(keyword) >= 0:
+            result.append(record)
+    return result
